# fpapicli
This is a Python CLI for Football Player API.

Link to API : [footballplayer-api](http://footballplayerapi.herokuapp.com/)

## Install
-- pip install fpapicli

-- pip install -e .

## Usage

-> fpapicli get-all

-> fpapicli get-player

for help -> fpapicli --help